@@ -40,6 +40,7 @@
 
 #include "format_ogg.h"
 #include "format_mp3.h"
+#include "format_ebml.h"
 
 #include "logging.h"
 #include "stats.h"
@@ -64,9 +65,21 @@ format_type_t format_get_type (const char *contenttype)
         return FORMAT_TYPE_OGG;
     else if(strcmp(contenttype, "video/ogg") == 0)
         return FORMAT_TYPE_OGG;
+    else if(strcmp(contenttype, "audio/webm") == 0)
+        return FORMAT_TYPE_EBML;
+    else if(strcmp(contenttype, "video/webm") == 0)
+        return FORMAT_TYPE_EBML;
+    else if(strcmp(contenttype, "audio/x-matroska") == 0)
+        return FORMAT_TYPE_EBML;
+    else if(strcmp(contenttype, "video/x-matroska") == 0)
+        return FORMAT_TYPE_EBML;
+    else if(strcmp(contenttype, "video/x-matroska-3d") == 0)
+        return FORMAT_TYPE_EBML;
     else
         /* We default to the Generic format handler, which
-           can handle many more formats than just mp3 */
+           can handle many more formats than just mp3.
+	   Let's warn that this is not well supported */
+	ICECAST_LOG_WARN("Unsupported or legacy stream type: \"%s\". Falling back to generic minimal handler for best effort.", contenttype);
         return FORMAT_TYPE_GENERIC;
 }
 
@@ -78,6 +91,9 @@ int format_get_plugin(format_type_t type, source_t *source)
     case FORMAT_TYPE_OGG:
         ret = format_ogg_get_plugin (source);
         break;
+    case FORMAT_TYPE_EBML:
+        ret = format_ebml_get_plugin (source);
+        break;
     case FORMAT_TYPE_GENERIC:
         ret = format_mp3_get_plugin (source);
         break;
@@ -205,11 +221,11 @@ int format_check_http_buffer (source_t *source, client_t *client)
 
     if (client->respcode == 0)
     {
-        DEBUG0("processing pending client headers");
+        ICECAST_LOG_DEBUG("processing pending client headers");
 
         if (format_prepare_headers (source, client) < 0)
         {
-            ERROR0 ("internal problem, dropping client");
+            ICECAST_LOG_ERROR("internal problem, dropping client");
             client->con->error = 1;
             return -1;
         }
@@ -278,14 +294,34 @@ static int format_prepare_headers (source_t *source, client_t *client)
     int bytes;
     int bitrate_filtered = 0;
     avl_node *node;
-    ice_config_t *config;
 
     remaining = client->refbuf->len;
     ptr = client->refbuf->data;
     client->respcode = 200;
 
-    bytes = snprintf (ptr, remaining, "HTTP/1.0 200 OK\r\n"
-            "Content-Type: %s\r\n", source->format->contenttype);
+    bytes = util_http_build_header(ptr, remaining, 0, 0, 200, NULL, source->format->contenttype, NULL, NULL, source);
+    if (bytes == -1) {
+        ICECAST_LOG_ERROR("Dropping client as we can not build response headers.");
+        client_send_500(client, "Header generation failed.");
+        return -1;
+    } else if ((bytes + 1024) >= remaining) { /* we don't know yet how much to follow but want at least 1kB free space */
+        void *new_ptr = realloc(ptr, bytes + 1024);
+        if (new_ptr) {
+            ICECAST_LOG_DEBUG("Client buffer reallocation succeeded.");
+            client->refbuf->data = ptr = new_ptr;
+            client->refbuf->len = remaining = bytes + 1024;
+            bytes = util_http_build_header(ptr, remaining, 0, 0, 200, NULL, source->format->contenttype, NULL, NULL, source);
+            if (bytes == -1 ) {
+                ICECAST_LOG_ERROR("Dropping client as we can not build response headers.");
+                client_send_500(client, "Header generation failed.");
+                return -1;
+            }
+        } else {
+            ICECAST_LOG_ERROR("Client buffer reallocation failed. Dropping client.");
+            client_send_500(client, "Buffer reallocation failed.");
+            return -1;
+        }
+    }
 
     remaining -= bytes;
     ptr += bytes;
@@ -321,7 +357,22 @@ static int format_prepare_headers (source_t *source, client_t *client)
             if (strcasecmp(var->name, "ice-password") &&
                 strcasecmp(var->name, "icy-metaint"))
             {
-                if (!strncasecmp("ice-", var->name, 4))
+		if (!strcasecmp(var->name, "ice-name"))
+		{
+		    ice_config_t *config;
+		    mount_proxy *mountinfo;
+
+		    config = config_get_config();
+		    mountinfo = config_find_mount (config, source->mount, MOUNT_TYPE_NORMAL);
+
+		    if (mountinfo && mountinfo->stream_name)
+		        bytes = snprintf (ptr, remaining, "icy-name:%s\r\n", mountinfo->stream_name);
+                    else
+		        bytes = snprintf (ptr, remaining, "icy-name:%s\r\n", var->value);
+
+                    config_release_config();
+		}
+                else if (!strncasecmp("ice-", var->name, 4))
                 {
                     if (!strcasecmp("ice-public", var->name))
                         bytes = snprintf (ptr, remaining, "icy-pub:%s\r\n", var->value);
@@ -348,17 +399,6 @@ static int format_prepare_headers (source_t *source, client_t *client)
     }
     avl_tree_unlock(source->parser->vars);
 
-    config = config_get_config();
-    bytes = snprintf (ptr, remaining, "Server: %s\r\n", config->server_id);
-    config_release_config();
-    remaining -= bytes;
-    ptr += bytes;
-
-    /* prevent proxy servers from caching */
-    bytes = snprintf (ptr, remaining, "Cache-Control: no-cache\r\n");
-    remaining -= bytes;
-    ptr += bytes;
-
     bytes = snprintf (ptr, remaining, "\r\n");
     remaining -= bytes;
     ptr += bytes;
