@@ -6,8 +6,10 @@
  * Copyright 2000-2004, Jack Moffitt <jack@xiph.org, 
  *                      Michael Smith <msmith@xiph.org>,
  *                      oddsock <oddsock@xiph.org>,
- *                      Karl Heyes <karl@xiph.org>
+ *                      Karl Heyes <karl@xiph.org>,
  *                      and others (see AUTHORS for details).
+ * Copyright 2011-2014, Philipp "ph3-der-loewe" Schafft <lion@lion.leolix.org>,
+ * Copyright 2014,      Thomas B. Ruecker <thomas@ruecker.fi>.
  */
 
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil; -*- */
@@ -41,9 +43,13 @@
 #include "net/resolver.h"
 #include "httpp/httpp.h"
 
-#ifdef CHUID
+#if HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
+#if HAVE_GRP_H
 #include <grp.h>
+#endif
+#if HAVE_PWD_H
 #include <pwd.h>
 #endif
 
@@ -71,7 +77,7 @@
 static int background;
 static char *pidfile = NULL;
 
-static void _fatal_error(char *perr)
+static void _fatal_error(const char *perr)
 {
 #ifdef WIN32_SERVICE
     MessageBox(NULL, perr, "Error", MB_SERVICE_NOTIFICATION);
@@ -85,11 +91,12 @@ static void _fatal_error(char *perr)
 static void _print_usage(void)
 {
     printf("%s\n\n", ICECAST_VERSION_STRING);
-    printf("usage: icecast [-b -v] -c <file>\n");
+    printf("usage: icecast [-b] -c <file>\n");
+    printf("or   : icecast {-v|--version}\n");
     printf("options:\n");
-    printf("\t-c <file>\tSpecify configuration file\n");
-    printf("\t-v\t\tDisplay version info\n");
-    printf("\t-b\t\tRun icecast in the background\n");
+    printf("\t-c <file>       Specify configuration file\n");
+    printf("\t-v or --version Display version info\n");
+    printf("\t-b              Run icecast in the background\n");
     printf("\n");
 }
 
@@ -170,7 +177,7 @@ static int _parse_config_opts(int argc, char **argv, char *filename, int size)
             background = 1;
 #endif
         }
-        if (strcmp(argv[i], "-v") == 0) {
+        if (strcmp(argv[i], "-v") == 0 || strcmp(argv[i], "--version") == 0) {
             fprintf(stdout, "%s\n", ICECAST_VERSION_STRING);
             exit(0);
         }
@@ -193,6 +200,16 @@ static int _parse_config_opts(int argc, char **argv, char *filename, int size)
         return -1;
 }
 
+static int _start_logging_stdout(void) {
+    errorlog = log_open_file(stderr);
+    if ( errorlog < 0 )
+        return 0;
+
+    log_set_level(errorlog, 2 /* WARN */);
+
+    return 1;
+}
+
 static int _start_logging(void)
 {
     char fn_error[FILENAME_MAX];
@@ -211,8 +228,7 @@ static int _start_logging(void)
             log_set_trigger (errorlog, config->logsize);
         log_set_archive_timestamp(errorlog, config->logarchive);
     } else {
-        errorlog = log_open_file(stderr);
-        log_to_stderr = 1;
+        /* this is already in place because of _start_logging_stdout() */
     }
 
     if (errorlog < 0) {
@@ -279,7 +295,7 @@ static int _start_listening(void)
 {
     int i;
     for(i=0; i < global.server_sockets; i++) {
-        if (sock_listen(global.serversock[i], ICE_LISTEN_QUEUE) == SOCK_ERROR)
+        if (sock_listen(global.serversock[i], ICECAST_LISTEN_QUEUE) == SOCK_ERROR)
             return 0;
 
         sock_set_blocking(global.serversock[i], 0);
@@ -332,11 +348,11 @@ static void _server_proc(void)
 
 /* chroot the process. Watch out - we need to do this before starting other
  * threads. Change uid as well, after figuring out uid _first_ */
-
+#if defined(HAVE_SETUID) || defined(HAVE_CHROOT) || defined(HAVE_SETUID)
 static void _ch_root_uid_setup(void)
 {
    ice_config_t *conf = config_get_config_unlocked();
-#ifdef CHUID
+#ifdef HAVE_SETUID
    struct passwd *user;
    struct group *group;
    uid_t uid=-1;
@@ -362,7 +378,7 @@ static void _ch_root_uid_setup(void)
    }
 #endif
 
-#ifdef CHROOT
+#if HAVE_CHROOT
    if (conf->chroot)
    {
        if(getuid()) /* root check */
@@ -380,8 +396,8 @@ static void _ch_root_uid_setup(void)
 
    }   
 #endif
-#ifdef CHUID
 
+#if HAVE_SETUID
    if(conf->chuid)
    {
        if(getuid()) /* root check */
@@ -390,14 +406,15 @@ static void _ch_root_uid_setup(void)
            return;
        }
 
-       if(gid != -1) {
+       if(uid != (uid_t)-1 && gid != (gid_t)-1) {
            if(!setgid(gid))
                fprintf(stdout, "Changed groupid to %i.\n", (int)gid);
            else
                fprintf(stdout, "Error changing groupid: %s.\n", strerror(errno));
-       }
-
-       if(uid != -1) {
+           if(!initgroups(conf->user, gid))
+               fprintf(stdout, "Changed supplementary groups based on user: %s.\n", conf->user);
+	   else
+               fprintf(stdout, "Error changing supplementary groups: %s.\n", strerror(errno));
            if(!setuid(uid))
                fprintf(stdout, "Changed userid to %i.\n", (int)uid);
            else
@@ -406,6 +423,7 @@ static void _ch_root_uid_setup(void)
    }
 #endif
 }
+#endif
 
 #ifdef WIN32_SERVICE
 int mainService(int argc, char **argv)
@@ -422,9 +440,14 @@ int main(int argc, char **argv)
     */
     res = _parse_config_opts(argc, argv, filename, 512);
     if (res == 1) {
-#if !defined(_WIN32) || defined(_CONSOLE)
+#if !defined(_WIN32) || defined(_CONSOLE) || defined(__MINGW32__) || defined(__MINGW64__)
         /* startup all the modules */
         initialize_subsystems();
+        if (!_start_logging_stdout()) {
+            _fatal_error("FATAL: Could not start logging on stderr.");
+            shutdown_subsystems();
+            return 1;
+        }
 #endif
         /* parse the config file */
         config_get_config();
@@ -449,7 +472,7 @@ int main(int argc, char **argv)
                 _fatal_error("XML config parsing error");
                 break;
             }
-#if !defined(_WIN32) || defined(_CONSOLE)
+#if !defined(_WIN32) || defined(_CONSOLE) || defined(__MINGW32__) || defined(__MINGW64__)
             shutdown_subsystems();
 #endif
             return 1;
@@ -469,12 +492,14 @@ int main(int argc, char **argv)
         return 1;
     }
 
+#if defined(HAVE_SETUID) || defined(HAVE_CHROOT) || defined(HAVE_SETUID)
     _ch_root_uid_setup(); /* Change user id and root if requested/possible */
+#endif
 
     stats_initialize(); /* We have to do this later on because of threading */
     fserve_initialize(); /* This too */
 
-#ifdef CHUID 
+#ifdef HAVE_SETUID 
     /* We'll only have getuid() if we also have setuid(), it's reasonable to
      * assume */
     if(!getuid()) /* Running as root! Don't allow this */
@@ -495,12 +520,12 @@ int main(int argc, char **argv)
         return 1;
     }
 
-    INFO1 ("%s server started", ICECAST_VERSION_STRING);
+    ICECAST_LOG_INFO("%s server started", ICECAST_VERSION_STRING);
 
     /* REM 3D Graphics */
 
     /* let her rip */
-    global.running = ICE_RUNNING;
+    global.running = ICECAST_RUNNING;
 
     /* Startup yp thread */
     yp_initialize();
@@ -511,8 +536,8 @@ int main(int argc, char **argv)
 
     _server_proc();
 
-    INFO0("Shutting down");
-#if !defined(_WIN32) || defined(_CONSOLE)
+    ICECAST_LOG_INFO("Shutting down");
+#if !defined(_WIN32) || defined(_CONSOLE) || defined(__MINGW32__) || defined(__MINGW64__)
     shutdown_subsystems();
 #endif
     if (pidfile)
