@@ -28,12 +28,21 @@
 #include <sys/socket.h>
 #include <sys/wait.h>
 #include <limits.h>
+#ifndef PATH_MAX
+#define PATH_MAX 4096
+#endif
 #else
 #include <winsock2.h>
 #include <windows.h>
 #define snprintf _snprintf
 #endif
 
+#ifndef _WIN32
+/* for __setup_empty_script_environment() */
+#include <sys/stat.h>
+#include <fcntl.h>
+#endif
+
 #include "thread/thread.h"
 #include "avl/avl.h"
 #include "httpp/httpp.h"
@@ -66,7 +75,7 @@ static int _free_client(void *key);
 static void _parse_audio_info (source_t *source, const char *s);
 static void source_shutdown (source_t *source);
 #ifdef _WIN32
-#define source_run_script(x,y)  WARN0("on [dis]connect scripts disabled");
+#define source_run_script(x,y)  ICECAST_LOG_WARN("on [dis]connect scripts disabled");
 #else
 static void source_run_script (char *command, char *mountpoint);
 #endif
@@ -80,7 +89,7 @@ source_t *source_reserve (const char *mount)
     source_t *src = NULL;
 
     if(mount[0] != '/')
-        WARN1("Source at \"%s\" does not start with '/', clients will be "
+        ICECAST_LOG_WARN("Source at \"%s\" does not start with '/', clients will be "
                 "unable to connect", mount);
 
     do
@@ -197,7 +206,7 @@ void source_clear_source (source_t *source)
 {
     int c;
 
-    DEBUG1 ("clearing source \"%s\"", source->mount);
+    ICECAST_LOG_DEBUG("clearing source \"%s\"", source->mount);
 
     avl_tree_wlock (source->pending_tree);
     client_destroy(source->client);
@@ -211,7 +220,7 @@ void source_clear_source (source_t *source)
 
     if (source->dumpfile)
     {
-        INFO1 ("Closing dumpfile for %s", source->mount);
+        ICECAST_LOG_INFO("Closing dumpfile for %s", source->mount);
         fclose (source->dumpfile);
         source->dumpfile = NULL;
     }
@@ -235,7 +244,7 @@ void source_clear_source (source_t *source)
     if (c)
     {
         stats_event_sub (NULL, "listeners", source->listeners);
-        INFO2 ("%d active listeners on %s released", c, source->mount);
+        ICECAST_LOG_INFO("%d active listeners on %s released", c, source->mount);
     }
     avl_tree_unlock (source->client_tree);
 
@@ -296,7 +305,7 @@ void source_clear_source (source_t *source)
 /* Remove the provided source from the global tree and free it */
 void source_free_source (source_t *source)
 {
-    DEBUG1 ("freeing source \"%s\"", source->mount);
+    ICECAST_LOG_DEBUG("freeing source \"%s\"", source->mount);
     avl_tree_wlock (global.source_tree);
     avl_delete (global.source_tree, source, NULL);
     avl_tree_unlock (global.source_tree);
@@ -345,7 +354,7 @@ void source_move_clients (source_t *source, source_t *dest)
     unsigned long count = 0;
     if (strcmp (source->mount, dest->mount) == 0)
     {
-        WARN1 ("src and dst are the same \"%s\", skipping", source->mount);
+        ICECAST_LOG_WARN("src and dst are the same \"%s\", skipping", source->mount);
         return;
     }
     /* we don't want the two write locks to deadlock in here */
@@ -356,7 +365,7 @@ void source_move_clients (source_t *source, source_t *dest)
     avl_tree_wlock (dest->pending_tree);
     if (dest->running == 0 && dest->on_demand == 0)
     {
-        WARN1 ("destination mount %s not running, unable to move clients ", dest->mount);
+        ICECAST_LOG_WARN("destination mount %s not running, unable to move clients ", dest->mount);
         avl_tree_unlock (dest->pending_tree);
         thread_mutex_unlock (&move_clients_mutex);
         return;
@@ -373,14 +382,14 @@ void source_move_clients (source_t *source, source_t *dest)
 
         if (source->on_demand == 0 && source->format == NULL)
         {
-            INFO1 ("source mount %s is not available", source->mount);
+            ICECAST_LOG_INFO("source mount %s is not available", source->mount);
             break;
         }
         if (source->format && dest->format)
         {
             if (source->format->type != dest->format->type)
             {
-                WARN2 ("stream %s and %s are of different types, ignored", source->mount, dest->mount);
+                ICECAST_LOG_WARN("stream %s and %s are of different types, ignored", source->mount, dest->mount);
                 break;
             }
         }
@@ -432,7 +441,7 @@ void source_move_clients (source_t *source, source_t *dest)
             avl_insert (dest->pending_tree, (void *)client);
             count++;
         }
-        INFO2 ("passing %lu listeners to \"%s\"", count, dest->mount);
+        ICECAST_LOG_INFO("passing %lu listeners to \"%s\"", count, dest->mount);
 
         source->listeners = 0;
         stats_event (source->mount, "listeners", "0");
@@ -462,7 +471,7 @@ static refbuf_t *get_next_buffer (source_t *source)
 
     if (source->short_delay)
         delay = 0;
-    while (global.running == ICE_RUNNING && source->running)
+    while (global.running == ICECAST_RUNNING && source->running)
     {
         int fds = 0;
         time_t current = time (NULL);
@@ -487,7 +496,7 @@ static refbuf_t *get_next_buffer (source_t *source)
         {
             if (! sock_recoverable (sock_error()))
             {
-                WARN0 ("Error while waiting on socket, Disconnecting source");
+                ICECAST_LOG_WARN("Error while waiting on socket, Disconnecting source");
                 source->running = 0;
             }
             break;
@@ -497,9 +506,9 @@ static refbuf_t *get_next_buffer (source_t *source)
             thread_mutex_lock(&source->lock);
             if ((source->last_read + (time_t)source->timeout) < current)
             {
-                DEBUG3 ("last %ld, timeout %d, now %ld", (long)source->last_read,
+                ICECAST_LOG_DEBUG("last %ld, timeout %d, now %ld", (long)source->last_read,
                         source->timeout, (long)current);
-                WARN0 ("Disconnecting source due to socket timeout");
+                ICECAST_LOG_WARN("Disconnecting source due to socket timeout");
                 source->running = 0;
             }
             thread_mutex_unlock(&source->lock);
@@ -509,7 +518,7 @@ static refbuf_t *get_next_buffer (source_t *source)
         refbuf = source->format->get_buffer (source);
         if (source->client->con && source->client->con->error)
         {
-            INFO1 ("End of Stream %s", source->mount);
+            ICECAST_LOG_INFO("End of Stream %s", source->mount);
             source->running = 0;
             continue;
         }
@@ -538,7 +547,7 @@ static void send_to_listener (source_t *source, client_t *client, int deletion_e
         if (client->con->discon_time)
             if (time(NULL) >= client->con->discon_time)
             {
-                INFO1 ("time limit reached for client #%lu", client->con->id);
+                ICECAST_LOG_INFO("time limit reached for client #%lu", client->con->id);
                 client->con->error = 1;
             }
 
@@ -572,7 +581,7 @@ static void send_to_listener (source_t *source, client_t *client, int deletion_e
      * if so, check to see if this client is still referring to it */
     if (deletion_expected && client->refbuf && client->refbuf == source->stream_data)
     {
-        INFO2 ("Client %lu (%s) has fallen too far behind, removing",
+        ICECAST_LOG_INFO("Client %lu (%s) has fallen too far behind, removing",
                 client->con->id, client->con->ip);
         stats_event_inc (source->mount, "slow_listeners");
         client->con->error = 1;
@@ -641,7 +650,7 @@ static void source_init (source_t *source)
         source->dumpfile = source_open_dumpfile (source->dumpfilename);
         if (source->dumpfile == NULL)
         {
-            WARN2("Cannot open dump file \"%s\" for appending: %s, disabling.",
+            ICECAST_LOG_WARN("Cannot open dump file \"%s\" for appending: %s, disabling.",
                     source->dumpfilename, strerror(errno));
         }
     }
@@ -658,7 +667,7 @@ static void source_init (source_t *source)
     stats_event_time (source->mount, "stream_start");
     stats_event_time_iso8601 (source->mount, "stream_start_iso8601");
 
-    DEBUG0("Source creation complete");
+    ICECAST_LOG_DEBUG("Source creation complete");
     source->last_read = time (NULL);
     source->prev_listeners = -1;
     source->running = 1;
@@ -702,7 +711,7 @@ void source_main (source_t *source)
 
     source_init (source);
 
-    while (global.running == ICE_RUNNING && source->running) {
+    while (global.running == ICECAST_RUNNING && source->running) {
         int remove_from_q;
 
         refbuf = get_next_buffer (source);
@@ -769,7 +778,7 @@ void source_main (source_t *source)
                     stats_event_dec (NULL, "listeners");
                 avl_delete(source->client_tree, (void *)client, _free_client);
                 source->listeners--;
-                DEBUG0("Client removed");
+                ICECAST_LOG_DEBUG("Client removed");
                 continue;
             }
             client_node = avl_get_next(client_node);
@@ -791,8 +800,8 @@ void source_main (source_t *source)
                 client_node = avl_get_next(client_node);
                 avl_delete(source->pending_tree, (void *)client, _free_client);
 
-                INFO0("Client deleted, exceeding maximum listeners for this "
-                        "mountpoint.");
+                ICECAST_LOG_INFO("Client deleted, exceeding maximum listeners for this "
+                        "mountpoint (%s).", source->mount);
                 continue;
             }
             
@@ -800,7 +809,7 @@ void source_main (source_t *source)
             avl_insert(source->client_tree, client_node->key);
 
             source->listeners++;
-            DEBUG0("Client added");
+            ICECAST_LOG_DEBUG("Client added for mountpoint (%s)", source->mount);
             stats_event_inc(source->mount, "connections");
 
             client_node = avl_get_next(client_node);
@@ -820,7 +829,7 @@ void source_main (source_t *source)
         if (source->listeners != source->prev_listeners)
         {
             source->prev_listeners = source->listeners;
-            INFO2("listener count on %s now %lu", source->mount, source->listeners);
+            ICECAST_LOG_INFO("listener count on %s now %lu", source->mount, source->listeners);
             if (source->listeners > source->peak_listeners)
             {
                 source->peak_listeners = source->listeners;
@@ -846,7 +855,7 @@ void source_main (source_t *source)
                 if (to_go->next == NULL || source->burst_point == to_go)
                 {
                     /* this should not happen */
-                    ERROR0 ("queue state is unexpected");
+                    ICECAST_LOG_ERROR("queue state is unexpected");
                     source->running = 0;
                     break;
                 }
@@ -869,7 +878,7 @@ static void source_shutdown (source_t *source)
     mount_proxy *mountinfo;
 
     source->running = 0;
-    INFO1("Source \"%s\" exiting", source->mount);
+    ICECAST_LOG_INFO("Source from %s at \"%s\" exiting", source->con->ip, source->mount);
 
     mountinfo = config_find_mount (config_get_config(), source->mount, MOUNT_TYPE_NORMAL);
     if (mountinfo)
@@ -985,7 +994,7 @@ static void source_apply_mount (source_t *source, mount_proxy *mountinfo)
     int val;
     http_parser_t *parser = NULL;
 
-    DEBUG1("Applying mount information for \"%s\"", source->mount);
+    ICECAST_LOG_DEBUG("Applying mount information for \"%s\"", source->mount);
     avl_tree_rlock (source->client_tree);
     stats_event_args (source->mount, "listener_peak", "%lu", source->peak_listeners);
 
@@ -1028,7 +1037,7 @@ static void source_apply_mount (source_t *source, mount_proxy *mountinfo)
     stats_event_args (source->mount, "public", "%d", val);
     if (source->yp_public != val)
     {
-        DEBUG1 ("YP changed to %d", val);
+        ICECAST_LOG_DEBUG("YP changed to %d", val);
         if (val)
             yp_add (source->mount);
         else
@@ -1176,7 +1185,7 @@ static void source_apply_mount (source_t *source, mount_proxy *mountinfo)
             if (f)
                 source->intro_file = f;
             else
-                WARN2 ("Cannot open intro file \"%s\": %s", path, strerror(errno));
+                ICECAST_LOG_WARN("Cannot open intro file \"%s\": %s", path, strerror(errno));
             free (path);
         }
     }
@@ -1222,18 +1231,18 @@ void source_update_settings (ice_config_t *config, source_t *source, mount_proxy
     source_apply_mount (source, mountinfo);
 
     if (source->fallback_mount)
-        DEBUG1 ("fallback %s", source->fallback_mount);
+        ICECAST_LOG_DEBUG("fallback %s", source->fallback_mount);
     if (mountinfo && mountinfo->intro_filename)
-        DEBUG1 ("intro file is %s", mountinfo->intro_filename);
+        ICECAST_LOG_DEBUG("intro file is %s", mountinfo->intro_filename);
     if (source->dumpfilename)
-        DEBUG1 ("Dumping stream to %s", source->dumpfilename);
+        ICECAST_LOG_DEBUG("Dumping stream to %s", source->dumpfilename);
     if (mountinfo && mountinfo->on_connect)
-        DEBUG1 ("connect script \"%s\"", mountinfo->on_connect);
+        ICECAST_LOG_DEBUG("connect script \"%s\"", mountinfo->on_connect);
     if (mountinfo && mountinfo->on_disconnect)
-        DEBUG1 ("disconnect script \"%s\"", mountinfo->on_disconnect);
+        ICECAST_LOG_DEBUG("disconnect script \"%s\"", mountinfo->on_disconnect);
     if (source->on_demand)
     {
-        DEBUG0 ("on_demand set");
+        ICECAST_LOG_DEBUG("on_demand set");
         stats_event (source->mount, "on_demand", "1");
         stats_event_args (source->mount, "listeners", "%ld", source->listeners);
     }
@@ -1243,7 +1252,7 @@ void source_update_settings (ice_config_t *config, source_t *source, mount_proxy
     if (source->hidden)
     {
         stats_event_hidden (source->mount, NULL, 1);
-        DEBUG0 ("hidden from public");
+        ICECAST_LOG_DEBUG("hidden from public");
     }
     else
         stats_event_hidden (source->mount, NULL, 0);
@@ -1256,12 +1265,12 @@ void source_update_settings (ice_config_t *config, source_t *source, mount_proxy
         snprintf (buf, sizeof (buf), "%ld", source->max_listeners);
         stats_event (source->mount, "max_listeners", buf);
     }
-    DEBUG1 ("public set to %d", source->yp_public);
-    DEBUG1 ("max listeners to %ld", source->max_listeners);
-    DEBUG1 ("queue size to %u", source->queue_size_limit);
-    DEBUG1 ("burst size to %u", source->burst_size);
-    DEBUG1 ("source timeout to %u", source->timeout);
-    DEBUG1 ("fallback_when_full to %u", source->fallback_when_full);
+    ICECAST_LOG_DEBUG("public set to %d", source->yp_public);
+    ICECAST_LOG_DEBUG("max listeners to %ld", source->max_listeners);
+    ICECAST_LOG_DEBUG("queue size to %u", source->queue_size_limit);
+    ICECAST_LOG_DEBUG("burst size to %u", source->burst_size);
+    ICECAST_LOG_DEBUG("source timeout to %u", source->timeout);
+    ICECAST_LOG_DEBUG("fallback_when_full to %u", source->fallback_when_full);
     thread_mutex_unlock(&source->lock);
 }
 
@@ -1311,6 +1320,33 @@ void source_client_callback (client_t *client, void *arg)
 
 
 #ifndef _WIN32
+/* this sets up the new environment for script execution.
+ * We ignore most failtures as we can not handle them anyway.
+ */
+static inline void __setup_empty_script_environment(void) {
+    int i;
+
+    /* close at least the first 1024 handles */
+    for (i = 0; i < 1024; i++)
+        close(i);
+
+    /* open null device */
+    i = open("/dev/null", O_RDWR);
+    if (i != -1) {
+        /* attach null device to stdin, stdout and stderr */
+        if (i != 0)
+            dup2(i, 0);
+        if (i != 1)
+            dup2(i, 1);
+        if (i != 2)
+            dup2(i, 2);
+
+        /* close null device */
+        if (i > 2)
+            close(i);
+    }
+}
+
 static void source_run_script (char *command, char *mountpoint)
 {
     pid_t pid, external_pid;
@@ -1323,19 +1359,24 @@ static void source_run_script (char *command, char *mountpoint)
             switch (pid = fork ())
             {
                 case -1:
-                    ERROR2 ("Unable to fork %s (%s)", command, strerror (errno));
+                    ICECAST_LOG_ERROR("Unable to fork %s (%s)", command, strerror (errno));
                     break;
                 case 0:  /* child */
-                    DEBUG1 ("Starting command %s", command);
-                    execl (command, command, mountpoint, (char *)NULL);
-                    ERROR2 ("Unable to run command %s (%s)", command, strerror (errno));
-                    exit(0);
+                    if (access(command, R_OK|X_OK) != 0) {
+                        ICECAST_LOG_ERROR("Unable to run command %s (%s)", command, strerror(errno));
+                        exit(1);
+                    }
+                    ICECAST_LOG_DEBUG("Starting command %s", command);
+                    __setup_empty_script_environment();
+                    /* consider to add action here as well */
+                    execl(command, command, mountpoint, (char *)NULL);
+                    exit(1);
                 default: /* parent */
                     break;
             }
             exit (0);
         case -1:
-            ERROR1 ("Unable to fork %s", strerror (errno));
+            ICECAST_LOG_ERROR("Unable to fork %s", strerror (errno));
             break;
         default: /* parent */
             waitpid (external_pid, NULL, 0);
@@ -1373,7 +1414,7 @@ static void *source_fallback_file (void *arg)
         file = fopen (path, "rb");
         if (file == NULL)
         {
-            WARN1 ("unable to open file \"%s\"", path);
+            ICECAST_LOG_WARN("unable to open file \"%s\"", path);
             free (path);
             break;
         }
@@ -1381,10 +1422,10 @@ static void *source_fallback_file (void *arg)
         source = source_reserve (mount);
         if (source == NULL)
         {
-            WARN1 ("mountpoint \"%s\" already reserved", mount);
+            ICECAST_LOG_WARN("mountpoint \"%s\" already reserved", mount);
             break;
         }
-        INFO1 ("mountpoint %s is reserved", mount);
+        ICECAST_LOG_INFO("mountpoint %s is reserved", mount);
         type = fserve_content_type (mount);
         parser = httpp_create_parser();
         httpp_initialize (parser, NULL);
@@ -1455,7 +1496,7 @@ void source_recheck_mounts (int update_all)
             stats_event (mount->mountname, NULL, NULL);
 
         /* check for fallback to file */
-        if (global.running == ICE_RUNNING && mount->fallback_mount)
+        if (global.running == ICECAST_RUNNING && mount->fallback_mount)
         {
             source_t *fallback = source_find_mount (mount->fallback_mount);
             if (fallback == NULL)
